RASER
======

**RA**diation **SE**miconducto**R** 


[![Latest Version][pypi-image]][pypi-url] 
  

Function
======

- SiC Detector Simulation 

Dependences 
======

- [ROOT](https://root.cern.ch) 
- [Geant4](https://geant4.web.cern.ch)
- [FEniCS](https://fenicsproject.org)


Documentation 
======

[X-Team/RASER](http://xteam.ihep.ac.cn/research/rd50/raser)


Contribution 
====== 
* Xin Shi, IHEP, @xshi
* Yuhang Tan, IHEP, @tanyh2018
* Tao Yang, IHEP, @yangtaogit
* Kai Liu, IHEP, @liukaihep
* Ryuta Kiuchi, IHEP, @rkiuchi
* Jianing Lin, Jilin U, @zombastar
* Yu Zhao, Liaoning U, @zylyz18
* Ziyi Zhao, Hunan Normal U, @zhaoziyi1
* Jia Wang, Hunan Normal U, @wangjia0203 
* Chenxi Fu, Jilin U, @heheda2001123
  


[pypi-image]: https://img.shields.io/pypi/v/raser.svg
[pypi-url]: https://pypi.org/project/raser

